@@ -48,7 +48,7 @@ def equalizeHist_use_mask(gray, mask, notuint8=False):
     bg_num = h * w - roi_num  # 背景区域像素个数
     gray *= mask
     dc = Counter(gray.flatten())
-    count = np.array([dc.get(i, 0) for i in range(mv + 1)], np.float)
+    count = np.array([dc.get(i, 0) for i in range(mv + 1)], float)
     count[0] -= bg_num  # 减去背景像素个数
     count = count / roi_num  # 得到概率
     # 计算累计概率
@@ -211,15 +211,19 @@ def _duration_params_validity_judgment(params):
             exit()
 
 
-def __get_params():
-    args = sys.argv
-    if len(args) == 1:
-        print(HELP)
-        exit()
-    if args[1] == '-h' or args[1] == '--help':
-        print(HELP)
-        exit()
-    cfg_p = Path(args[1])
+def __get_params(config_path=None):
+    if config_path is None:
+        args = sys.argv
+        if len(args) == 1:
+            print(HELP)
+            exit()
+        if args[1] == '-h' or args[1] == '--help':
+            print(HELP)
+            exit()
+        cfg_p = Path(args[1])
+    else:
+        cfg_p = Path(config_path)
+
     if not cfg_p.exists():
         print('please check that if the config file path is correct')
         exit()
